@@ -61,7 +61,7 @@ int main(int argc, char *argv[])
     //解决Qt在Retina屏幕上图片模糊问题
     QApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
     app->setOrganizationName("deepin");
-    app->setApplicationName("dde-lock");
+    app->setApplicationName("org.deepin.dde.lock");
     app->setApplicationVersion("2015.1.0");
 
     //注册全局事件过滤器
@@ -172,6 +172,9 @@ int main(int argc, char *argv[])
         QObject::connect(lockFrame, &LockFrame::sendTokenToAuth, worker, &LockWorker::sendTokenToAuth);
         QObject::connect(lockFrame, &LockFrame::requestEndAuthentication, worker, &LockWorker::endAuthentication);
         QObject::connect(lockFrame, &LockFrame::authFinished, worker, &LockWorker::onAuthFinished);
+        if (model->isUseWayland()) {
+            QObject::connect(lockFrame, &LockFrame::requestDisableGlobalShortcutsForWayland, worker, &LockWorker::disableGlobalShortcutsForWayland);
+        }
         lockFrame->setVisible(model->visible());
         emit lockService.Visible(true);
         return lockFrame;
