@@ -182,10 +182,11 @@ static void set_auto_QT_SCALE_FACTOR() {
 }
 
 // 初次启动时，设置一下鼠标的默认位置
-void set_pointer() {
+void set_pointer()
+{
     auto set_position = [ = ] (QPoint p) {
         Display *dpy;
-        dpy = XOpenDisplay(0);
+        dpy = XOpenDisplay(nullptr);
 
         if (!dpy) return;
 
@@ -226,7 +227,7 @@ int main(int argc, char* argv[])
     DApplication a(argc, argv);
     QApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
     qApp->setOrganizationName("deepin");
-    qApp->setApplicationName("lightdm-deepin-greeter");
+    qApp->setApplicationName("org.deepin.dde.lightdm-deepin-greeter");
     qApp->setApplicationVersion("2015.1.0");
     qApp->setAttribute(Qt::AA_ForceRasterWidgets);
 
@@ -263,21 +264,24 @@ int main(int argc, char* argv[])
     QDBusConnectionInterface *interface = QDBusConnection::systemBus().interface();
     if (!interface->isServiceRegistered(serviceName)) {
         qWarning() << "accounts service is not registered wait...";
-        QEventLoop eventLoop;
 
         QDBusServiceWatcher *serviceWatcher = new QDBusServiceWatcher(serviceName, QDBusConnection::systemBus());
-        QObject::connect(serviceWatcher, &QDBusServiceWatcher::serviceRegistered, &eventLoop, &QEventLoop::quit);
         QObject::connect(serviceWatcher, &QDBusServiceWatcher::serviceUnregistered, [ = ] (const QString &service) {
             if (service == serviceName) {
                 qCritical() << "ERROR, accounts service unregistered, what should I do?";
             }
         });
 
+#ifdef ENABLE_WAITING_ACCOUNTS_SERVICE
+        qDebug() << "waiting for deepin accounts service";
+        QEventLoop eventLoop;
+        QObject::connect(serviceWatcher, &QDBusServiceWatcher::serviceRegistered, &eventLoop, &QEventLoop::quit);
 #ifdef  QT_DEBUG
         QTimer::singleShot(10000, &eventLoop, &QEventLoop::quit);
 #endif
         eventLoop.exec();
-        qDebug() << "service OK!";
+        qDebug() << "service registered!";
+#endif
     }
 
     SessionBaseModel *model = new SessionBaseModel();
@@ -298,7 +302,7 @@ int main(int argc, char* argv[])
     PropertyGroup *property_group = new PropertyGroup(worker);
     property_group->addProperty("contentVisible");
 
-    auto createFrame = [&](QScreen *screen, int count) -> QWidget * {
+    auto createFrame = [&](QPointer<QScreen> screen, int count) -> QWidget * {
         LoginWindow *loginFrame = new LoginWindow(model);
         loginFrame->setScreen(screen, count <= 0);
         property_group->addObject(loginFrame);
@@ -326,5 +330,7 @@ int main(int argc, char* argv[])
     checker.start();
 #endif
 
+    model->setVisible(true);
+
     return a.exec();
 }
