@@ -33,9 +33,8 @@ LockWorker::LockWorker(SessionBaseModel *const model, QObject *parent)
     , m_limitsUpdateTimer(new QTimer(this))
     , m_sessionManagerInter(new SessionManagerInter("com.deepin.SessionManager", "/com/deepin/SessionManager", QDBusConnection::sessionBus(), this))
     , m_switchosInterface(new HuaWeiSwitchOSInterface("com.huawei", "/com/huawei/switchos", QDBusConnection::sessionBus(), this))
-    , m_accountsInter(new AccountsInter("com.deepin.daemon.Accounts", "/com/deepin/daemon/Accounts", QDBusConnection::systemBus(), this))
-    , m_loginedInter(new LoginedInter("com.deepin.daemon.Accounts", "/com/deepin/daemon/Logined", QDBusConnection::systemBus(), this))
-    , m_gsettings(nullptr)
+    , m_kglobalaccelInter(nullptr)
+    , m_kwinInter(nullptr)
 {
     initConnections();
     initData();
@@ -98,7 +97,7 @@ void LockWorker::initConnections()
     connect(m_authFramework, &DeepinAuthFramework::FactorsInfoChanged, m_model, &SessionBaseModel::updateFactorsInfo);
     /* com.deepin.dde.LockService */
     connect(m_lockInter, &DBusLockService::UserChanged, this, [=](const QString &json) {
-        qDebug() << "DBusLockService::UserChanged:" << json;
+        qInfo() << "DBusLockService::UserChanged:" << json;
         QTimer::singleShot(100, this, [ = ] {
             m_model->setCurrentModeState(SessionBaseModel::ModeStatus::PasswordMode);
         });
@@ -113,7 +112,7 @@ void LockWorker::initConnections()
     });
     /* org.freedesktop.login1.Session */
     connect(m_login1SessionSelf, &Login1SessionSelf::ActiveChanged, this, [=](bool active) {
-        qDebug() << "DBusLockService::ActiveChanged:" << active;
+        qInfo() << "DBusLockService::ActiveChanged:" << active;
         if (active) {
             createAuthentication(m_model->currentUser()->name());
         } else {
@@ -123,7 +122,7 @@ void LockWorker::initConnections()
     });
     /* org.freedesktop.login1.Manager */
     connect(m_login1Inter, &DBusLogin1Manager::PrepareForSleep, this, [=](bool isSleep) {
-        qDebug() << "DBusLogin1Manager::PrepareForSleep:" << isSleep;
+        qInfo() << "DBusLogin1Manager::PrepareForSleep:" << isSleep;
         if (isSleep) {
             endAuthentication(m_account, AT_All);
             destoryAuthentication(m_account);
@@ -134,6 +133,7 @@ void LockWorker::initConnections()
     });
     /* model */
     connect(m_model, &SessionBaseModel::authTypeChanged, this, [=](const int type) {
+        qInfo() << "Auth type changed: " << type;
         if (type > 0 && m_model->getAuthProperty().MFAFlag) {
             startAuthentication(m_account, type);
         }
@@ -152,7 +152,6 @@ void LockWorker::initConnections()
             destoryAuthentication(m_model->currentUser()->name());
             setCurrentUser(m_model->currentUser());
         }
-        setLocked(visible);
     });
     connect(m_model, &SessionBaseModel::onStatusChanged, this, [=](SessionBaseModel::ModeStatus state) {
         if (state == SessionBaseModel::ModeStatus::PowerMode || state == SessionBaseModel::ModeStatus::ShutDownMode) {
@@ -165,6 +164,7 @@ void LockWorker::initConnections()
             m_model->updateLimitedInfo(m_authFramework->GetLimitedInfo(m_account));
     });
     connect(m_dbusInter, &DBusObjectInter::NameOwnerChanged, this, [=](const QString &name, const QString &oldOwner, const QString &newOwner) {
+        Q_UNUSED(oldOwner)
         if (name == "com.deepin.daemon.Authenticate" && newOwner != "" && m_model->visible() && m_sessionManagerInter->locked()) {
             m_resetSessionTimer->stop();
             endAuthentication(m_account, AT_All);
@@ -222,6 +222,10 @@ void LockWorker::initData()
     m_model->updateSupportedEncryptionType(m_authFramework->GetSupportedEncrypts());
     m_model->updateSupportedMixAuthFlags(m_authFramework->GetSupportedMixAuthFlags());
     m_model->updateLimitedInfo(m_authFramework->GetLimitedInfo(m_model->currentUser()->name()));
+    if (m_model->isUseWayland()) {
+        m_kglobalaccelInter = new QDBusInterface("org.kde.kglobalaccel","/kglobalaccel","org.kde.KGlobalAccel", QDBusConnection::sessionBus(), this);
+        m_kwinInter = new QDBusInterface("org.kde.KWin","/KWin","org.kde.KWin", QDBusConnection::sessionBus(), this);
+    }
 }
 
 void LockWorker::initConfiguration()
@@ -278,7 +282,7 @@ void LockWorker::onAuthStateChanged(const int type, const int state, const QStri
                 endAuthentication(m_account, type);
                 if (!m_model->currentUser()->limitsInfo(type).locked
                         && type != AT_Face && type != AT_Iris) {
-                    QTimer::singleShot(50, this, [ this, type ] {
+                    QTimer::singleShot(50, this, [this, type] {
                         startAuthentication(m_account, type);
                     });
                 }
@@ -299,6 +303,7 @@ void LockWorker::onAuthStateChanged(const int type, const int state, const QStri
                 break;
             case AS_Timeout:
             case AS_Error:
+                qWarning() << "Auth error, type: " << type << ", state: " << state << ", message: " << message;
                 endAuthentication(m_account, type);
                 m_model->updateAuthState(type, state, message);
                 break;
@@ -331,7 +336,7 @@ void LockWorker::onAuthStateChanged(const int type, const int state, const QStri
                 endAuthentication(m_account, type);
                 // 人脸和虹膜需要手动重新开启验证
                 if (!m_model->currentUser()->limitsInfo(type).locked && type != AT_Face && type != AT_Iris) {
-                    QTimer::singleShot(50, this, [ this, type ] {
+                    QTimer::singleShot(50, this, [this, type] {
                         startAuthentication(m_account, type);
                     });
                 }
@@ -384,16 +389,18 @@ void LockWorker::doPowerAction(const SessionBaseModel::PowerAction action)
     }
         break;
     case SessionBaseModel::PowerAction::RequireRestart:
-        if (m_model->currentModeState() == SessionBaseModel::ModeStatus::ShutDownMode) {
+        if (!isLocked()) {
             m_sessionManagerInter->RequestReboot();
         } else {
+            createAuthentication(m_account);
             m_model->setCurrentModeState(SessionBaseModel::ModeStatus::ConfirmPasswordMode);
         }
         return;
     case SessionBaseModel::PowerAction::RequireShutdown:
-        if (m_model->currentModeState() == SessionBaseModel::ModeStatus::ShutDownMode) {
+        if (!isLocked()) {
             m_sessionManagerInter->RequestShutdown();
         } else {
+            createAuthentication(m_account);
             m_model->setCurrentModeState(SessionBaseModel::ModeStatus::ConfirmPasswordMode);
         }
         return;
@@ -425,6 +432,7 @@ void LockWorker::doPowerAction(const SessionBaseModel::PowerAction action)
  */
 void LockWorker::setCurrentUser(const std::shared_ptr<User> user)
 {
+    qInfo() << "Set current user: " << user->name();
     QJsonObject json;
     json["AuthType"] = user->lastAuthType();
     json["Name"] = user->name();
@@ -438,7 +446,13 @@ void LockWorker::switchToUser(std::shared_ptr<User> user)
     qDebug() << "LockWorker::switchToUser:" << m_account << user->name();
     if (user->name() == m_account || *user == *m_model->currentUser()) {
         qInfo() << "switch to current user:" << user->name() << user->isLogin();
-        createAuthentication(user->name());
+        if (!m_authFramework->authSessionExist(m_account)) {
+            createAuthentication(user->name());
+        } else {
+            endAuthentication(m_account, AT_All);
+            destoryAuthentication(m_account);
+            createAuthentication(m_account);
+        }
         return;
     } else {
         qInfo() << "switch user from" << m_account << "to" << user->name() << user->isLogin();
@@ -499,7 +513,7 @@ void LockWorker::setLocked(const bool locked)
  */
 void LockWorker::createAuthentication(const QString &account)
 {
-    qDebug() << "LockWorker::createAuthentication:" << account;
+    qInfo() << "LockWorker::createAuthentication:" << account;
     QString userPath = m_accountsInter->FindUserByName(account);
     if (!userPath.startsWith("/")) {
         qWarning() << userPath;
@@ -522,6 +536,8 @@ void LockWorker::createAuthentication(const QString &account)
         m_model->setAuthType(AT_PAM);
         break;
     }
+
+    setLocked(true);
 }
 
 /**
@@ -531,7 +547,7 @@ void LockWorker::createAuthentication(const QString &account)
  */
 void LockWorker::destoryAuthentication(const QString &account)
 {
-    qDebug() << "LockWorker::destoryAuthentication:" << account;
+    qInfo() << "LockWorker::destoryAuthentication:" << account;
     switch (m_model->getAuthProperty().FrameworkState) {
     case Available:
         m_authFramework->DestoryAuthController(account);
@@ -551,7 +567,7 @@ void LockWorker::destoryAuthentication(const QString &account)
  */
 void LockWorker::startAuthentication(const QString &account, const int authType)
 {
-    qDebug() << "LockWorker::startAuthentication:" << account << authType;
+    qInfo() << "LockWorker::startAuthentication:" << account << authType;
     switch (m_model->getAuthProperty().FrameworkState) {
     case Available:
         m_authFramework->StartAuthentication(account, authType, -1);
@@ -571,7 +587,7 @@ void LockWorker::startAuthentication(const QString &account, const int authType)
  */
 void LockWorker::sendTokenToAuth(const QString &account, const int authType, const QString &token)
 {
-    qDebug() << "LockWorker::sendTokenToAuth:" << account << authType;
+    qInfo() << "LockWorker::sendTokenToAuth:" << account << authType;
     switch (m_model->getAuthProperty().FrameworkState) {
     case Available:
         m_authFramework->SendTokenToAuth(account, authType, token);
@@ -602,6 +618,7 @@ void LockWorker::endAuthentication(const QString &account, const int authType)
 
 void LockWorker::lockServiceEvent(quint32 eventType, quint32 pid, const QString &username, const QString &message)
 {
+    Q_UNUSED(pid)
     if (!m_model->currentUser())
         return;
 
@@ -690,6 +707,7 @@ void LockWorker::onUnlockFinished(bool unlocked)
         break;
     }
 
+    setLocked(!unlocked);
     emit m_model->authFinished(unlocked);
 }
 
@@ -699,3 +717,26 @@ void LockWorker::restartResetSessionTimer()
         m_resetSessionTimer->start();
     }
 }
+
+void LockWorker::disableGlobalShortcutsForWayland(const bool enable)
+{
+    if (m_kwinInter == nullptr || m_kglobalaccelInter == nullptr) {
+        return;
+    }
+    if (!m_kwinInter->isValid()) {
+        qWarning() << "kwinInter is not valid";
+        return;
+    }
+    QDBusReply<void> reply = m_kwinInter->call("disableGlobalShortcutsForClient", enable);
+    if (!reply.isValid()) {
+        qWarning() << "call disableGlobalShortcutsForClient failed" << reply.error();
+    }
+    if (!m_kglobalaccelInter->isValid()) {
+        qWarning() << "kglobalaccelInter is not valid";
+        return;
+    }
+    reply = m_kglobalaccelInter->call("setActiveByUniqueName", "Screenshot", true);
+    if (!reply.isValid()) {
+        qWarning() << "call setActiveByUniqueName failed" << reply.error();
+    }
+}
