@@ -47,6 +47,8 @@ public slots:
     void onAuthFinished();
     void onAuthStateChanged(const int type, const int state, const QString &message);
 
+    void disableGlobalShortcutsForWayland(const bool enable);
+
 private:
     void initConnections();
     void initData();
@@ -73,10 +75,9 @@ private:
     SessionManagerInter *m_sessionManagerInter;
     HuaWeiSwitchOSInterface *m_switchosInterface = nullptr;
     bool m_canAuthenticate = false;
-    AccountsInter *m_accountsInter;
-    LoginedInter *m_loginedInter;
     QString m_account;
-    QGSettings* m_gsettings;
+    QDBusInterface *m_kglobalaccelInter;
+    QDBusInterface *m_kwinInter;
 };
 
 #endif // LOCKWORKER_H
