@@ -26,6 +26,8 @@
 #ifndef CONSTANTS_H
 #define CONSTANTS_H
 
+#include <DSysInfo>
+
 #include <QString>
 #include <QStringList>
 
@@ -49,6 +51,8 @@ static const int KEYBOARDLAYOUT_WIDTH = 200;
 
 static const int CapslockWarningWidth = 23;
 static const int CapslockWarningRightMargin = 8;
+static const int BASE_SCREEN_HEIGHT = 1080;
+static const int MIN_AUTH_WIDGET_HEIGHT = 276; // 密码验证时整个登录控件的大小，默认为最小高度（不考虑无密码登录的情况，稍许影响）
 
 const QStringList session_ui_configs {
     "/etc/lightdm/lightdm-deepin-greeter.conf",
@@ -65,13 +69,19 @@ const QStringList SHUTDOWN_CONFIGS {
 };
 
 static const QString SOLID_BACKGROUND_COLOR = "#000F27";        // 纯色背景色号
-static const QString LOCK_DCONFIG_SOURCE = "com.deepin.dde.dde-lock.dconfig"; // 锁屏配置文件
-static const QString LOGIN_DCONFIG_SOURCE = "com.deepin.dde.lightdm-deepin-greeter.dconfig"; // 登录配置文件
+static const QString LOCK_DCONFIG_SOURCE = "org.deepin.dde.lock"; // 锁屏配置文件
+static const QString LOGIN_DCONFIG_SOURCE = "org.deepin.dde.lightdm-deepin-greeter"; // 登录配置文件
 
 enum AuthFactorType {
     SingleAuthFactor,
     MultiAuthFactor,
 };
+
+using namespace Dtk::Core;
+
+const DSysInfo::UosEdition UosEdition = DSysInfo::uosEditionType();
+const bool IsCommunitySystem = (DSysInfo::UosCommunity == UosEdition);//是否是社区版
+
 }
 
 
