@@ -21,22 +21,9 @@ using namespace Auth;
 using namespace AuthCommon;
 DCORE_USE_NAMESPACE
 
-class UserNumlockSettings
-{
-public:
-    UserNumlockSettings(const QString &username)
-        : m_username(username)
-        , m_settings(QSettings::UserScope, "deepin", "greeter")
-    {
-    }
-
-    int get(const int defaultValue) { return m_settings.value(m_username, defaultValue).toInt(); }
-    void set(const int value) { m_settings.setValue(m_username, value); }
-
-private:
-    QString m_username;
-    QSettings m_settings;
-};
+const int NUM_LOCKED = 0;   // 禁用小键盘
+const int NUM_UNLOCKED = 1; // 启用小键盘
+const int NUM_LOCK_UNKNOWN = 2; // 未知状态
 
 GreeterWorker::GreeterWorker(SessionBaseModel *const model, QObject *parent)
     : AuthInterface(model, parent)
@@ -132,7 +119,7 @@ void GreeterWorker::initConnections()
     connect(m_authFramework, &DeepinAuthFramework::PromptChanged, m_model, &SessionBaseModel::updatePrompt);
     /* org.freedesktop.login1.Session */
     connect(m_login1SessionSelf, &Login1SessionSelf::ActiveChanged, this, [=](bool active) {
-        qDebug() << "Login1SessionSelf::ActiveChanged:" << active;
+        qInfo() << "Login1SessionSelf::ActiveChanged:" << active;
         if (m_model->currentUser() == nullptr || m_model->currentUser()->name().isEmpty()) {
             return;
         }
@@ -147,7 +134,7 @@ void GreeterWorker::initConnections()
     });
     /* org.freedesktop.login1.Manager */
     connect(m_login1Inter, &DBusLogin1Manager::PrepareForSleep, this, [=](bool isSleep) {
-        qDebug() << "DBusLogin1Manager::PrepareForSleep:" << isSleep;
+        qInfo() << "DBusLogin1Manager::PrepareForSleep:" << isSleep;
         // 登录界面待机或休眠时提供显示假黑屏，唤醒时显示正常界面
         m_model->setIsBlackMode(isSleep);
 
@@ -159,27 +146,40 @@ void GreeterWorker::initConnections()
         }
     });
     connect(m_login1Inter, &DBusLogin1Manager::SessionRemoved, this, [this] {
-        qDebug() << "DBusLogin1Manager::SessionRemoved";
-        m_model->updateCurrentUser(m_lockInter->CurrentUser());
-        m_model->updateAuthState(AT_All, AS_Cancel, "Cancel");
-        destoryAuthentication(m_account);
-        if (!m_model->currentUser()->isNoPasswordLogin()) {
-            createAuthentication(m_model->currentUser()->name());
-        } else {
-            m_model->setAuthType(AT_None);
+        qInfo() << "DBusLogin1Manager::SessionRemoved";
+        if (m_model->updateCurrentUser(m_lockInter->CurrentUser())) {
+            m_model->updateAuthState(AT_All, AS_Cancel, "Cancel");
+            destoryAuthentication(m_account);
+            if (!m_model->currentUser()->isNoPasswordLogin()) {
+                createAuthentication(m_model->currentUser()->name());
+            } else {
+                m_model->setAuthType(AT_None);
+            }
         }
         m_soundPlayerInter->PrepareShutdownSound(static_cast<int>(m_model->currentUser()->uid()));
     });
     /* com.deepin.dde.LockService */
     connect(m_lockInter, &DBusLockService::UserChanged, this, [=](const QString &json) {
-        qDebug() << "DBusLockService::UserChanged:" << json;
+        qInfo() << "DBusLockService::UserChanged:" << json;
+        // 如果是已登录用户则返回，否则已登录用户和未登录用户来回切换时会造成用户信息错误
+        std::shared_ptr<User> user_ptr = m_model->json2User(json);
+        if (!user_ptr || user_ptr->isLogin())
+            return;
+
         m_resetSessionTimer->stop();
+        m_model->updateCurrentUser(user_ptr);
+        const QString &account = user_ptr->name();
+        if (user_ptr.get()->isNoPasswordLogin()) {
+            emit m_model->authTypeChanged(AT_None);
+            m_account = account;
+        }
         QTimer::singleShot(100, this, [ = ] {
             m_model->setCurrentModeState(SessionBaseModel::ModeStatus::PasswordMode);
         });
     });
     /* model */
     connect(m_model, &SessionBaseModel::authTypeChanged, this, [=](const int type) {
+        qInfo() << "Auth type changed: " << type;
         if (type > 0 && m_model->getAuthProperty().MFAFlag) {
             startAuthentication(m_account, m_model->getAuthProperty().AuthType);
         }
@@ -199,7 +199,7 @@ void GreeterWorker::initConnections()
     });
     /* others */
     connect(KeyboardMonitor::instance(), &KeyboardMonitor::numlockStatusChanged, this, [=](bool on) {
-        saveNumlockStatus(m_model->currentUser(), on);
+        saveNumlockState(m_model->currentUser(), on);
     });
     connect(m_limitsUpdateTimer, &QTimer::timeout, this, [this] {
         if (m_authFramework->isDeepinAuthValid())
@@ -263,16 +263,16 @@ void GreeterWorker::initConfiguration()
         m_model->setCanSleep(false);
     }
 
-    //当这个配置不存在是，如果是不是笔记本就打开小键盘，否则就关闭小键盘 0关闭键盘 1打开键盘 2默认值（用来判断是不是有这个key）
-    if (m_model->currentUser() != nullptr && UserNumlockSettings(m_model->currentUser()->name()).get(2) == 2) {
+    // 当这个配置不存在是，如果是不是笔记本就打开小键盘，否则就关闭小键盘 0关闭键盘 1打开键盘 2默认值（用来判断是不是有这个key）
+    if (m_model->currentUser() != nullptr && getNumLockState(m_model->currentUser()->name()) == NUM_LOCK_UNKNOWN) {
         PowerInter powerInter("com.deepin.system.Power", "/com/deepin/system/Power", QDBusConnection::systemBus(), this);
         if (powerInter.hasBattery()) {
-            saveNumlockStatus(m_model->currentUser(), 0);
+            saveNumlockState(m_model->currentUser(), false);
         } else {
-            saveNumlockStatus(m_model->currentUser(), 1);
+            saveNumlockState(m_model->currentUser(), true);
         }
-        recoveryUserKBState(m_model->currentUser());
     }
+    recoveryUserKBState(m_model->currentUser());
 }
 
 void GreeterWorker::doPowerAction(const SessionBaseModel::PowerAction action)
@@ -370,7 +370,7 @@ bool GreeterWorker::isSecurityEnhanceOpen()
  */
 void GreeterWorker::createAuthentication(const QString &account)
 {
-    qDebug() << "GreeterWorker::createAuthentication:" << account;
+    qInfo() << "GreeterWorker::createAuthentication:" << account;
     m_account = account;
     if (account.isEmpty() || account == "...") {
         m_model->setAuthType(AT_None);
@@ -651,7 +651,7 @@ void GreeterWorker::authenticationComplete()
 
 void GreeterWorker::onAuthFinished()
 {
-    qDebug() << "GreeterWorker::onAuthFinished";
+    qInfo() << "GreeterWorker::onAuthFinished";
     if (m_greeter->inAuthentication()) {
         m_greeter->respond(m_authFramework->AuthSessionPath(m_account) + QString(";") + m_password);
         if (m_model->currentUser()->expiredState() == User::ExpiredAlready) {
@@ -781,9 +781,37 @@ void GreeterWorker::onCurrentUserChanged(const std::shared_ptr<User> &user)
     loadTranslation(user->locale());
 }
 
-void GreeterWorker::saveNumlockStatus(std::shared_ptr<User> user, const bool &on)
+void GreeterWorker::saveNumlockState(std::shared_ptr<User> user, bool on)
 {
-    UserNumlockSettings(user->name()).set(on);
+    QStringList list = getDConfigValue(getDefaultConfigFileName(), "numLockState", QStringList()).toStringList();
+    const QString &userName = user->name();
+
+    // 移除当前用户的记录
+    for (const QString &numLockState : list) {
+        QStringList tmpList = numLockState.split(":");
+        if (tmpList.size() == 2 && tmpList.at(0) == userName) {
+            list.removeAll(numLockState);
+            break;
+        }
+    }
+
+    // 插入当前用户的记录
+    list.append(user->name() + ":" + (on ? "True" : "False"));
+    setDConfigValue(getDefaultConfigFileName(), "numLockState", list);
+}
+
+int GreeterWorker::getNumLockState(const QString &userName)
+{
+    QStringList list = getDConfigValue(getDefaultConfigFileName(), "numLockState", QStringList()).toStringList();
+
+    for (const QString &numLockState : list) {
+        QStringList tmpList = numLockState.split(":");
+        if (tmpList.size() == 2 && tmpList.at(0) == userName) {
+            return "True" == tmpList.at(1) ? NUM_UNLOCKED : NUM_LOCKED;
+        }
+    }
+
+    return NUM_LOCK_UNKNOWN;
 }
 
 void GreeterWorker::recoveryUserKBState(std::shared_ptr<User> user)
@@ -795,7 +823,7 @@ void GreeterWorker::recoveryUserKBState(std::shared_ptr<User> user)
     if (user.get() == nullptr)
         return;
 
-    const bool enabled = UserNumlockSettings(user->name()).get(false);
+    const bool enabled = getNumLockState(user->name()) == NUM_UNLOCKED;
 
     qWarning() << "restore numlock state to " << enabled;
 
