@@ -48,11 +48,11 @@ LoginWindow::LoginWindow(SessionBaseModel *const model, QWidget *parent)
 #endif
     });
 
-    connect(model, &SessionBaseModel::authFinished, this, [ = ](bool successd) {
-        setEnterEnable(!successd);
-        if (successd) {
-            m_loginContent->setVisible(!successd);
-        }
+    connect(model, &SessionBaseModel::visibleChanged, this, &LoginWindow::setVisible);
+    connect(model, &SessionBaseModel::authFinished, this, [ = ](bool successful) {
+        setEnterEnable(!successful);
+        if (successful)
+            m_loginContent->setVisible(false);
 
 #ifdef DISABLE_LOGIN_ANI
         // 在认证成功以后会通过更改背景来实现登录动画，但是禁用登录动画的情况下，会立即调用startSession，
@@ -68,13 +68,7 @@ LoginWindow::LoginWindow(SessionBaseModel *const model, QWidget *parent)
     connect(m_loginContent, &LockContent::requestStartAuthentication, this, &LoginWindow::requestStartAuthentication);
     connect(m_loginContent, &LockContent::sendTokenToAuth, this, &LoginWindow::sendTokenToAuth);
     connect(m_loginContent, &LockContent::requestEndAuthentication, this, &LoginWindow::requestEndAuthentication);
-    connect(m_loginContent, &LockContent::authFinished, this, [this]{
-        setEnterEnable(true);
-        if (m_model->currentUser()->expiredState() != User::ExpiredAlready)
-            m_loginContent->hide();
-        emit authFinished();
-    });
-    connect(model, &SessionBaseModel::blackModeChanged, this, &FullscreenBackground::setIsBlackMode);
+    connect(m_loginContent, &LockContent::authFinished, this, &LoginWindow::authFinished);
 }
 
 void LoginWindow::showEvent(QShowEvent *event)
@@ -83,7 +77,6 @@ void LoginWindow::showEvent(QShowEvent *event)
 
     //greeter界面显示时，需要调用虚拟键盘
     m_model->setHasVirtualKB(true);
-    m_model->setVisible(true);
 }
 
 void LoginWindow::hideEvent(QHideEvent *event)
@@ -92,5 +85,4 @@ void LoginWindow::hideEvent(QHideEvent *event)
 
     //greeter界面隐藏时，需要结束虚拟键盘
     m_model->setHasVirtualKB(false);
-    m_model->setVisible(false);
 }
