@@ -72,10 +72,10 @@ SessionWidget::SessionWidget(QWidget *parent)
     , m_frameDataBind(FrameDataBind::Instance())
     , m_sessionModel(new QLightDM::SessionsModel(this))
     , m_userModel(new QLightDM::UsersModel(this))
-    , m_allowSwitchingToWayland(getDConfigValue(getDefaultConfigFileName(), "allow-switching-to-wayland", false).toBool())
+    , m_allowSwitchingToWayland(getDConfigValue(getDefaultConfigFileName(), "allowSwitchingToWayland", false).toBool())
     , m_isWaylandExisted(false)
     , m_warningLabel(new QLabel(this))
-    , m_defaultSession(getDConfigValue(getDefaultConfigFileName(),"default-session-name", DEFAULT_SESSION_NAME).toString())
+    , m_defaultSession(getDConfigValue(getDefaultConfigFileName(),"defaultSession", DEFAULT_SESSION_NAME).toString())
 {
     setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
     loadSessionList();
@@ -97,6 +97,17 @@ SessionWidget::SessionWidget(QWidget *parent)
     QTimer::singleShot(0, this, [ = ] {
         m_frameDataBind->refreshData("SessionWidget");
     });
+
+    // 判断显卡是否支持wayland
+    if (m_allowSwitchingToWayland) {
+        QDBusInterface systemDisplayInter("com.deepin.system.Display", "/com/deepin/system/Display",
+                "com.deepin.system.Display", QDBusConnection::systemBus(), this);
+        QDBusReply<bool> reply  = systemDisplayInter.call("SupportWayland");
+        if (QDBusError::NoError == reply.error().type())
+            m_allowSwitchingToWayland = reply.value();
+        else
+            qWarning() << "Get support wayland property failed: " << reply.error().message();
+    }
 }
 
 void SessionWidget::setModel(SessionBaseModel *const model)
