@@ -36,6 +36,8 @@
 #include <QDesktopWidget>
 #include <QDBusReply>
 #include <QWindow>
+#include <QValidator>
+#include <QRegExp>
 
 #include <unistd.h>
 
@@ -80,6 +82,8 @@ void AuthPassword::initUI()
     m_lineEdit->setContextMenuPolicy(Qt::NoContextMenu);
     m_lineEdit->setFocusPolicy(Qt::StrongFocus);
     m_lineEdit->lineEdit()->setAlignment(Qt::AlignCenter);
+    m_lineEdit->lineEdit()->setValidator(new QRegExpValidator(QRegExp("^[ -~]+$")));
+
     setLineEditInfo(tr("Password"), PlaceHolderText);
 
     QHBoxLayout *passwordLayout = new QHBoxLayout(m_lineEdit->lineEdit());
@@ -125,6 +129,7 @@ void AuthPassword::initConnections()
         emit focusChanged(focus);
     });
     connect(m_lineEdit, &DLineEditEx::textChanged, this, [this](const QString &text) {
+        m_lineEdit->hideAlertMessage();
         m_lineEdit->setAlert(false);
         emit lineEditTextChanged(text);
     });
@@ -293,8 +298,7 @@ void AuthPassword::setLimitsInfo(const LimitsInfo &info)
     m_passwordHintBtn->setVisible(info.numFailures > 0 && !m_passwordHint.isEmpty());
     if (m_limitsInfo->locked) {
         setAuthState(AS_Locked, "Locked");
-        if (lockStateChanged && this->isVisible() && QFile::exists(ResetPassword_Exe_Path) &&
-            m_currentUid <= 9999 && isUserAccountBinded()) {
+        if (this->isVisible() && QFile::exists(ResetPassword_Exe_Path) && m_currentUid <= 9999 && !IsCommunitySystem ) {
             qDebug() << "begin reset passoword";
             setResetPasswordMessageVisible(true);
             updateResetPasswordUI();
@@ -315,7 +319,7 @@ void AuthPassword::setLineEditInfo(const QString &text, const TextType type)
 {
     switch (type) {
     case AlertText:
-        m_lineEdit->showAlertMessage(text, this, 3000);
+        m_lineEdit->showAlertMessage(text, this, 5000);
         m_lineEdit->setAlert(true);
         break;
     case InputText: {
@@ -399,7 +403,7 @@ void AuthPassword::updateUnlockPrompt()
  */
 void AuthPassword::showPasswordHint()
 {
-    m_lineEdit->showAlertMessage(m_passwordHint, this, 3000);
+    m_lineEdit->showAlertMessage(m_passwordHint, this, 5000);
 }
 
 /**
@@ -418,7 +422,16 @@ void AuthPassword::setPasswordHintBtnVisible(const bool isVisible)
  */
 void AuthPassword::setResetPasswordMessageVisible(const bool isVisible)
 {
+    qDebug() << "set reset password message visible: " << isVisible;
+    if (m_resetPasswordMessageVisible == isVisible)
+        return;
+
+    // 如果设置为显示重置按钮，但是实际上并没有锁定，直接退出，是是否锁定为准
+    if (isVisible && !isLocked())
+        return;
+
     m_resetPasswordMessageVisible = isVisible;
+    emit resetPasswordMessageVisibleChanged(m_resetPasswordMessageVisible);
 }
 
 /**
@@ -451,14 +464,15 @@ void AuthPassword::showResetPasswordMessage()
     m_resetPasswordFloatingMessage->setMessage(tr("Forgot password?"));
     connect(suggestButton, &QPushButton::clicked, this, [ this ] {
         if (window()->windowHandle() && window()->windowHandle()->setKeyboardGrabEnabled(false)) {
-            qDebug() << "setKeyboardGrabEnabled(false) success！";
+            qDebug() << "setKeyboardGrabEnabled(false) success!";
         }
         const QString AccountsService("com.deepin.daemon.Accounts");
         const QString path = QString("/com/deepin/daemon/Accounts/User%1").arg(m_currentUid);
         com::deepin::daemon::accounts::User user(AccountsService, path, QDBusConnection::systemBus());
         auto reply = user.SetPassword("");
         reply.waitForFinished();
-        qWarning() << "reply setpassword:" << reply.error().message();
+        if (reply.isError())
+            qWarning() << "reply setpassword:" << reply.error().message();
 
         emit m_resetPasswordFloatingMessage->closeButtonClicked();
     });
@@ -564,7 +578,6 @@ void AuthPassword::updateResetPasswordUI()
     } else {
         closeResetPasswordMessage();
     }
-    emit resetPasswordMessageVisibleChanged(m_resetPasswordMessageVisible);
 }
 
 bool AuthPassword::eventFilter(QObject *watched, QEvent *event)
@@ -585,5 +598,6 @@ void AuthPassword::hideEvent(QHideEvent *event)
     m_lineEdit->setAlert(false);
     m_lineEdit->hideAlertMessage();
     setLineEditInfo(tr("Password"), PlaceHolderText);
+    closeResetPasswordMessage();
     AuthModule::hideEvent(event);
 }
