@@ -34,6 +34,8 @@
 #include <QDesktopWidget>
 #include <QDBusReply>
 #include <QWindow>
+#include <QValidator>
+#include <QRegExp>
 
 #include <unistd.h>
 #include <com_deepin_daemon_accounts_user.h>
@@ -78,6 +80,7 @@ void AuthSingle::initUI()
     m_lineEdit->setContextMenuPolicy(Qt::NoContextMenu);
     m_lineEdit->setFocusPolicy(Qt::StrongFocus);
     m_lineEdit->lineEdit()->setAlignment(Qt::AlignCenter);
+    m_lineEdit->lineEdit()->setValidator(new QRegExpValidator(QRegExp("^[ -~]+$")));
 
     QHBoxLayout *passwordLayout = new QHBoxLayout(m_lineEdit->lineEdit());
     passwordLayout->setContentsMargins(0, 0, 10, 0);
@@ -270,7 +273,7 @@ void AuthSingle::setLimitsInfo(const LimitsInfo &info)
     setPasswordHintBtnVisible(info.numFailures > 0 && !m_passwordHint.isEmpty());
     if (m_limitsInfo->locked) {
         if (lockStateChanged && this->isVisible() && QFile::exists(ResetPassword_Exe_Path) &&
-            m_currentUid <= 9999 && isUserAccountBinded()) {
+            m_currentUid <= 9999 && !IsCommunitySystem ) {
             qDebug() << "begin reset passoword";
             setResetPasswordMessageVisible(true);
             updateResetPasswordUI();
@@ -310,7 +313,7 @@ void AuthSingle::setLineEditInfo(const QString &text, const TextType type)
 {
     switch (type) {
     case AlertText:
-        m_lineEdit->showAlertMessage(text, this, 3000);
+        m_lineEdit->showAlertMessage(text, this, 5000);
         m_lineEdit->setAlert(true);
         break;
     case InputText: {
@@ -374,7 +377,15 @@ void AuthSingle::setKeyboardButtonVisible(const bool visible)
  */
 void AuthSingle::setResetPasswordMessageVisible(const bool isVisible)
 {
+    if (m_resetPasswordMessageVisible == isVisible)
+        return;
+
+    // 如果设置为显示重置按钮，但是实际上并没有锁定，直接退出，是是否锁定为准
+    if (isVisible && !isLocked())
+        return;
+
     m_resetPasswordMessageVisible = isVisible;
+    emit resetPasswordMessageVisibleChanged(m_resetPasswordMessageVisible);
 }
 
 /**
@@ -411,7 +422,7 @@ void AuthSingle::updateUnlockPrompt()
  */
 void AuthSingle::showPasswordHint()
 {
-    m_lineEdit->showAlertMessage(m_passwordHint, this, 3000);
+    m_lineEdit->showAlertMessage(m_passwordHint, this, 5000);
 }
 
 /**
@@ -567,7 +578,6 @@ void AuthSingle::updateResetPasswordUI()
     } else {
         closeResetPasswordMessage();
     }
-    emit resetPasswordMessageVisibleChanged(m_resetPasswordMessageVisible);
 }
 
 bool AuthSingle::eventFilter(QObject *watched, QEvent *event)
@@ -580,5 +590,10 @@ bool AuthSingle::eventFilter(QObject *watched, QEvent *event)
             return true;
         }
     }
+
+    if (watched == this && event->type() == QEvent::Hide) {
+        closeResetPasswordMessage();
+    }
+
     return false;
 }
