@@ -49,16 +49,13 @@ LockContent::LockContent(SessionBaseModel *const model, QWidget *parent)
     m_localServer->setSocketOptions(QLocalServer::WorldAccessOption);
     static bool once = false;
     if (!once) {
-        if (!m_localServer->listen("GrabKeyboard")) { // 监听特定的连接
+        // 将greeter和lock的服务名称分开
+        // 如果服务相同，但是创建套接字文件的用户不一样，greeter和lock不能删除对方的套接字文件，造成锁屏无法监听服务。
+        QString serverName = QString("GrabKeyboard_") + (m_model->appType() == Login ? "greeter" : ("lock_" + m_model->currentUser()->name()));
+        // 将之前的server删除，如果是旧文件，即使监听成功，客户端也无法连接。
+        QLocalServer::removeServer(serverName);
+        if (!m_localServer->listen(serverName)) { // 监听特定的连接
             qWarning() << "listen failed!" << m_localServer->errorString();
-            if(m_localServer->serverError() == QAbstractSocket::AddressInUseError) {
-                QLocalServer::removeServer("GrabKeyboard");
-                if (!m_localServer->listen("GrabKeyboard")) {
-                    qWarning() << "listen failed again!" << m_localServer->serverName() << m_localServer->errorString();
-                } else {
-                    qDebug() << "listen success!";
-                }
-            }
         } else {
             qDebug() << "listen success!";
         }
@@ -191,6 +188,9 @@ void LockContent::initSFAWidget()
     connect(m_sfaWidget, &SFAWidget::requestEndAuthentication, this, &LockContent::requestEndAuthentication);
     connect(m_sfaWidget, &SFAWidget::requestCheckAccount, this, &LockContent::requestCheckAccount);
     connect(m_sfaWidget, &SFAWidget::authFinished, this, &LockContent::authFinished);
+    connect(m_sfaWidget, &SFAWidget::updateParentLayout, this, [this] {
+        m_centerSpacerItem->changeSize(0, m_sfaWidget->getTopSpacing());
+    });
 }
 
 /**
@@ -203,6 +203,7 @@ void LockContent::initUserListWidget()
     }
     m_userListWidget = new UserFrameList(this);
     m_userListWidget->setModel(m_model);
+    m_userListWidget->setVisible(false);
 
     connect(m_userListWidget, &UserFrameList::clicked, this, &LockContent::restoreMode);
     connect(m_userListWidget, &UserFrameList::requestSwitchUser, this, &LockContent::requestSwitchToUser);
@@ -249,10 +250,7 @@ void LockContent::pushPasswordFrame()
 {
     setCenterContent(m_authWidget, Qt::AlignTop, m_authWidget->getTopSpacing());
 
-    SFAWidget *sfaWidget = qobject_cast<SFAWidget *>(m_authWidget);
-    if (sfaWidget) {
-        sfaWidget->syncResetPasswordUI();
-    }
+    m_authWidget->syncResetPasswordUI();
 }
 
 void LockContent::pushUserFrame()
@@ -296,11 +294,13 @@ void LockContent::onNewConnection()
     if (m_localServer->hasPendingConnections()) {
         QLocalSocket *socket = m_localServer->nextPendingConnection();
         connect(socket, &QLocalSocket::disconnected, this, &LockContent::onDisConnect);
-        connect(socket, &QLocalSocket::readyRead, this, [socket, this]{
+        connect(socket, &QLocalSocket::readyRead, this, [socket, this] {
             auto content = socket->readAll();
             if (content == "close") {
-                m_sfaWidget->syncPasswordResetPasswordVisibleChanged(QVariant::fromValue(true));
-                m_sfaWidget->syncResetPasswordUI();
+                if (m_authWidget) {
+                    m_authWidget->syncPasswordResetPasswordVisibleChanged(QVariant::fromValue(true));
+                    m_authWidget->syncResetPasswordUI();
+                }
             }
         });
     }
@@ -348,10 +348,11 @@ void LockContent::mouseReleaseEvent(QMouseEvent *event)
 
     //在关机界面没有点击按钮直接点击界面时，直接隐藏关机界面
     if (m_model->currentModeState() == SessionBaseModel::ShutDownMode) {
-        hideToplevelWindow();
+        m_model->setVisible(false);
     }
 
-    if (m_model->currentModeState() == SessionBaseModel::UserMode) {
+    if (m_model->currentModeState() == SessionBaseModel::UserMode
+        || m_model->currentModeState() == SessionBaseModel::PowerMode) {
         // 触屏点击空白处不退出用户列表界面
         if (event->source() == Qt::MouseEventSynthesizedByQt)
             return SessionBaseWindow::mouseReleaseEvent(event);
@@ -362,20 +363,20 @@ void LockContent::mouseReleaseEvent(QMouseEvent *event)
 
     m_model->setCurrentModeState(SessionBaseModel::ModeStatus::PasswordMode);
 
-    return SessionBaseWindow::mouseReleaseEvent(event);
+    SessionBaseWindow::mouseReleaseEvent(event);
 }
 
 void LockContent::showEvent(QShowEvent *event)
 {
     onStatusChanged(m_model->currentModeState());
     tryGrabKeyboard();
-    return QFrame::showEvent(event);
+    QFrame::showEvent(event);
 }
 
 void LockContent::hideEvent(QHideEvent *event)
 {
     m_shutdownFrame->recoveryLayout();
-    return QFrame::hideEvent(event);
+    QFrame::hideEvent(event);
 }
 
 void LockContent::resizeEvent(QResizeEvent *event)
@@ -498,12 +499,10 @@ void LockContent::onUserListChanged(QList<std::shared_ptr<User> > list)
 
 void LockContent::tryGrabKeyboard()
 {
-#ifdef QT_DEBUG
-    return;
-#endif
-
-    if (qgetenv("XDG_SESSION_TYPE").contains("wayland"))
+#ifndef QT_DEBUG
+    if (m_model->isUseWayland()) {
         return;
+    }
 
     if (window()->windowHandle() && window()->windowHandle()->setKeyboardGrabEnabled(true)) {
         m_failures = 0;
@@ -513,7 +512,9 @@ void LockContent::tryGrabKeyboard()
     m_failures++;
 
     if (m_failures == 15) {
-        qDebug() << "Trying grabkeyboard has exceeded the upper limit. dde-lock will quit.";
+        qWarning() << "Trying grabkeyboard has exceeded the upper limit. dde-lock will quit.";
+
+        m_failures = 0;
 
         DDBusSender()
             .service("org.freedesktop.Notifications")
@@ -530,20 +531,12 @@ void LockContent::tryGrabKeyboard()
             .arg(5000)
             .call();
 
-        hide();
+        emit requestLockFrameHide();
+        return;
     }
 
     QTimer::singleShot(100, this, &LockContent::tryGrabKeyboard);
-}
-
-void LockContent::hideToplevelWindow()
-{
-    QWidgetList widgets = qApp->topLevelWidgets();
-    for (QWidget *widget : widgets) {
-        if (widget->isVisible()) {
-            widget->hide();
-        }
-    }
+#endif
 }
 
 void LockContent::currentWorkspaceChanged()
@@ -596,23 +589,22 @@ void LockContent::refreshLayout(SessionBaseModel::ModeStatus status)
 void LockContent::keyPressEvent(QKeyEvent *event)
 {
     switch (event->key()) {
-    case Qt::Key_Return ... Qt::Key_Enter: {
+    case Qt::Key_Return:
+    case Qt::Key_Enter:
         if (m_mfaWidget) {
             m_mfaWidget->autoUnlock();
         }
         break;
-    }
-    case Qt::Key_Escape: {
+    case Qt::Key_Escape:
         if (m_model->currentModeState() == SessionBaseModel::ModeStatus::ConfirmPasswordMode) {
             m_model->setAbortConfirm(false);
             m_model->setPowerAction(SessionBaseModel::PowerAction::None);
         } else if (m_model->currentModeState() == SessionBaseModel::ModeStatus::ShutDownMode) {
-            hideToplevelWindow();
             m_model->setCurrentModeState(SessionBaseModel::ModeStatus::PasswordMode);
+            m_model->setVisible(false);
         } else if (m_model->currentModeState() == SessionBaseModel::ModeStatus::PowerMode) {
             m_model->setCurrentModeState(SessionBaseModel::ModeStatus::PasswordMode);
         }
         break;
     }
-    }
 }
