@@ -34,6 +34,7 @@
 
 MFAWidget::MFAWidget(QWidget *parent)
     : AuthWidget(parent)
+    , m_index(0)
     , m_mainLayout(new QVBoxLayout(this))
 {
     setObjectName(QStringLiteral("MFAWidget"));
@@ -67,7 +68,7 @@ void MFAWidget::initConnections()
     AuthWidget::initConnections();
     connect(m_model, &SessionBaseModel::authTypeChanged, this, &MFAWidget::setAuthType);
     connect(m_model, &SessionBaseModel::authStateChanged, this, &MFAWidget::setAuthState);
-    connect(m_accountEdit, &DLineEditEx::textChanged, this, [this](const QString &value) {
+    connect(m_accountEdit, &DLineEditEx::textChanged, this, [](const QString &value) {
         FrameDataBind::Instance()->updateValue("MFAAccount", value);
     });
 }
@@ -244,9 +245,11 @@ void MFAWidget::initPasswdAuth()
 {
     if (m_passwordAuth) {
         m_passwordAuth->reset();
+        m_mainLayout->insertWidget(m_index, m_passwordAuth);
         return;
     }
     m_passwordAuth = new AuthPassword(this);
+    m_passwordAuth->setCurrentUid(m_model->currentUser()->uid());
     m_passwordAuth->setCapsLockVisible(m_capslockMonitor->isCapslockOn());
     m_passwordAuth->setPasswordHint(m_user->passwordHint());
     m_mainLayout->insertWidget(m_index, m_passwordAuth);
@@ -273,10 +276,17 @@ void MFAWidget::initPasswdAuth()
     /* 输入框数据同步 */
     std::function<void(QVariant)> passwordChanged = std::bind(&MFAWidget::syncPassword, this, std::placeholders::_1);
     m_registerFunctions["MFPasswordAuth"] = FrameDataBind::Instance()->registerFunction("MFPasswordAuth", passwordChanged);
-    connect(m_passwordAuth, &AuthPassword::lineEditTextChanged, this, [this](const QString &value) {
+    connect(m_passwordAuth, &AuthPassword::lineEditTextChanged, this, [](const QString &value) {
         FrameDataBind::Instance()->updateValue("MFPasswordAuth", value);
     });
     FrameDataBind::Instance()->refreshData("MFPasswordAuth");
+    /* 重置密码可见性数据同步 */
+    std::function<void(QVariant)> resetPasswordVisibleChanged = std::bind(&AuthWidget::syncPasswordResetPasswordVisibleChanged, this, std::placeholders::_1);
+    m_registerFunctions["MFResetPasswordVisible"] = FrameDataBind::Instance()->registerFunction("MFResetPasswordVisible", resetPasswordVisibleChanged);
+    connect(m_passwordAuth, &AuthPassword::resetPasswordMessageVisibleChanged, this, [ = ](const bool value) {
+        FrameDataBind::Instance()->updateValue("MFResetPasswordVisible", value);
+    });
+    FrameDataBind::Instance()->refreshData("MFResetPasswordVisible");
 
     connect(m_passwordAuth, &AuthPassword::requestChangeFocus, this, &MFAWidget::updateFocusPosition);
 }
@@ -288,6 +298,7 @@ void MFAWidget::initFingerprintAuth()
 {
     if (m_fingerprintAuth) {
         m_fingerprintAuth->reset();
+        m_mainLayout->insertWidget(m_index, m_fingerprintAuth);
         return;
     }
     m_fingerprintAuth = new AuthFingerprint(this);
@@ -309,6 +320,7 @@ void MFAWidget::initUKeyAuth()
 {
     if (m_ukeyAuth) {
         m_ukeyAuth->reset();
+        m_mainLayout->insertWidget(m_index, m_ukeyAuth);
         return;
     }
     m_ukeyAuth = new AuthUKey(this);
@@ -355,6 +367,7 @@ void MFAWidget::initFaceAuth()
 {
     if (m_faceAuth) {
         m_faceAuth->reset();
+        m_mainLayout->insertWidget(m_index, m_faceAuth);
         return;
     }
     m_faceAuth = new AuthFace(this);
@@ -376,6 +389,7 @@ void MFAWidget::initIrisAuth()
 {
     if (m_irisAuth) {
         m_irisAuth->reset();
+        m_mainLayout->insertWidget(m_index, m_irisAuth);
         return;
     }
     m_irisAuth = new AuthIris(this);
@@ -444,3 +458,24 @@ void MFAWidget::updateFocusPosition()
     }
     setFocus();
 }
+
+/**
+ * @brief 计算需要增加的顶部间隔(加在用户头像的上方)，以实现用户头像到屏幕顶端的距离为屏幕高度的35%
+ */
+int MFAWidget::getTopSpacing() const
+{
+    const int calcTopHeight = static_cast<int>(topLevelWidget()->geometry().height() * AUTH_WIDGET_TOP_SPACING_PERCENT);
+    // 验证类型数量*高度
+    const int authWidgetHeight = (m_index - 2) * 47 + MIN_AUTH_WIDGET_HEIGHT;
+
+    // 当分辨率过低时，如果仍然保持用户头像到屏幕顶端的距离为屏幕高度的35%，那么验证窗口整体时偏下的。
+    // 计算当验证窗口居中时距离屏幕顶端的高度，与屏幕高度*0.35对比取较小值。
+    const int centerTop = static_cast<int>((topLevelWidget()->geometry().height() - authWidgetHeight) / 2);
+    const int topHeight = qMin(calcTopHeight, centerTop);
+
+    // 需要额外增加的顶部间隔高度 = 屏幕高度*0.35 - 验证窗口高度 - 时间控件高度 - 布局间隔
+    const int deltaY = topHeight - calcCurrentHeight(LOCK_CONTENT_TOP_WIDGET_HEIGHT)
+            - calcCurrentHeight(LOCK_CONTENT_CENTER_LAYOUT_MARGIN);
+
+    return qMax(15, deltaY);
+}
