@@ -31,11 +31,13 @@
 #include "modules_loader.h"
 #include "tray_module_interface.h"
 #include "tipswidget.h"
+#include "public_func.h"
 
 #include <DFloatingButton>
 #include <DArrowRectangle>
 #include <DPushButton>
 #include <dimagebutton.h>
+#include <DConfig>
 
 #include <QEvent>
 #include <QGraphicsDropShadowEffect>
@@ -48,6 +50,25 @@
 #define BUTTON_SIZE QSize(52,52)
 
 using namespace dss;
+DCORE_USE_NAMESPACE
+
+bool FlotingButton::eventFilter(QObject *watch, QEvent *event)
+{
+    if (watch == this) {
+        if (event->type() == QEvent::MouseButtonRelease) {
+            QMouseEvent *e = static_cast<QMouseEvent *>(event);
+            if (e->button() == Qt::RightButton) {
+                Q_EMIT requestShowMenu();
+            }
+        } else if (event->type() == QEvent::Enter) {
+            Q_EMIT requestShowTips();
+        } else if (event->type() == QEvent::Leave || event->type() == QEvent::MouseButtonPress) {
+            Q_EMIT requestHideTips();
+        }
+    }
+
+    return false;
+}
 
 ControlWidget::ControlWidget(const SessionBaseModel *model, QWidget *parent)
     : QWidget(parent)
@@ -56,6 +77,8 @@ ControlWidget::ControlWidget(const SessionBaseModel *model, QWidget *parent)
     , m_arrowRectWidget(new DArrowRectangle(DArrowRectangle::ArrowBottom, this))
     , m_kbLayoutListView(nullptr)
     , m_keyboardBtn(nullptr)
+    , m_onboardBtnVisible(true)
+    , m_dconfig(DConfig::create(getDefaultConfigFileName(), getDefaultConfigFileName(), QString(), this))
 {
     setModel(model);
     initUI();
@@ -111,7 +134,7 @@ void ControlWidget::initKeyboardLayoutList()
     m_arrowRectWidget->setFocusPolicy(Qt::NoFocus);
 
     QPalette pal = m_arrowRectWidget->palette();
-    pal.setColor(DPalette::Inactive, DPalette::Base, QColor(235, 235, 235, 0.05 * 255));
+    pal.setColor(DPalette::Inactive, DPalette::Base, QColor(235, 235, 235, int(0.05 * 255)));
     setPalette(pal);
 
     m_arrowRectWidget->setContent(m_kbLayoutListView);
@@ -121,7 +144,8 @@ void ControlWidget::initKeyboardLayoutList()
 
 void ControlWidget::setVirtualKBVisible(bool visible)
 {
-    m_virtualKBBtn->setVisible(visible);
+    m_onboardBtnVisible = visible;
+    m_virtualKBBtn->setVisible(visible && !m_dconfig->value("hideOnboard", false).toBool());
 }
 
 void ControlWidget::initUI()
@@ -216,6 +240,11 @@ void ControlWidget::initConnect()
     connect(m_virtualKBBtn, &DFloatingButton::clicked, this, &ControlWidget::requestSwitchVirtualKB);
     connect(m_keyboardBtn, &DFloatingButton::clicked, this, &ControlWidget::setKBLayoutVisible);
     connect(m_model, &SessionBaseModel::currentUserChanged, this, &ControlWidget::setUser);
+    connect(m_dconfig, &DConfig::valueChanged, this, [this] (const QString &key) {
+        if (m_virtualKBBtn && key == "hideOnboard") {
+            m_virtualKBBtn->setVisible(m_onboardBtnVisible && !m_dconfig->value("hideOnboard", false).toBool());
+        }
+    });
 }
 
 void ControlWidget::addModule(module::BaseModuleInterface *module)
@@ -600,14 +629,9 @@ void ControlWidget::keyReleaseEvent(QKeyEvent *event)
         rightKeySwitch();
         break;
     case Qt::Key_Tab:
-        for (const auto btn : m_btnList) {
-            if (btn->hasFocus()) {
-                m_index = m_btnList.indexOf(btn);
-                break;
-            }
-        }
-        break;
-    default:
+        auto it = std::find_if(m_btnList.begin(), m_btnList.end(),
+                               [](DFloatingButton *btn) { return btn->hasFocus(); });
+        m_index = it != m_btnList.end() ? m_btnList.indexOf(it.i->t()) : 0;
         break;
     }
 }
