@@ -27,16 +27,16 @@
 #define CONTROLWIDGET_H
 
 #include <dtkwidget_global.h>
+#include <dtkcore_global.h>
 #include "userinfo.h"
 
+#include <DFloatingButton>
 #include <DBlurEffectWidget>
 
 #include <QWidget>
 #include <QEvent>
 #include <QMouseEvent>
 
-#include <DFloatingButton>
-
 namespace dss {
 namespace module {
 class BaseModuleInterface;
@@ -49,6 +49,10 @@ DWIDGET_BEGIN_NAMESPACE
 class DArrowRectangle;
 DWIDGET_END_NAMESPACE
 
+DCORE_BEGIN_NAMESPACE
+class DConfig;
+DCORE_END_NAMESPACE
+
 class MediaWidget;
 class QHBoxLayout;
 class QPropertyAnimation;
@@ -92,22 +96,7 @@ Q_SIGNALS:
     void requestHideTips();
 
 protected:
-    bool eventFilter(QObject *watch, QEvent *event) {
-        if (watch == this) {
-            if (event->type() == QEvent::MouseButtonRelease) {
-                QMouseEvent *e = static_cast<QMouseEvent *>(event);
-                if (e->button() == Qt::RightButton) {
-                    Q_EMIT requestShowMenu();
-                }
-            } else if (event->type() == QEvent::Enter) {
-                Q_EMIT requestShowTips();
-            } else if (event->type() == QEvent::Leave) {
-                Q_EMIT requestHideTips();
-            }
-        }
-
-        return false;
-    }
+    bool eventFilter(QObject *watch, QEvent *event) override;
 };
 class ControlWidget : public QWidget
 {
@@ -179,6 +168,8 @@ private:
     DFloatingButton *m_keyboardBtn;         // 键盘布局按钮
     std::shared_ptr<User> m_curUser;
     QList<QMetaObject::Connection> m_connectionList;
+    bool m_onboardBtnVisible;
+    DTK_CORE_NAMESPACE::DConfig *m_dconfig;
 };
 
 #endif // CONTROLWIDGET_H
