@@ -24,8 +24,10 @@
  */
 
 #include "fullscreenbackground.h"
-#include "sessionbasemodel.h"
+
+#include "black_widget.h"
 #include "public_func.h"
+#include "sessionbasemodel.h"
 
 #include <DGuiApplicationHelper>
 
@@ -56,13 +58,13 @@ FullscreenBackground::FullscreenBackground(SessionBaseModel *model, QWidget *par
     , m_fadeOutAni(nullptr)
     , m_imageEffectInter(new ImageEffectInter("com.deepin.daemon.ImageEffect", "/com/deepin/daemon/ImageEffect", QDBusConnection::systemBus(), this))
     , m_model(model)
-    , m_originalCursor(cursor())
     , m_useSolidBackground(false)
     , m_fadeOutAniFinished(false)
     , m_enableAnimation(true)
+    , m_blackWidget(new BlackWidget(this))
 {
 #ifndef QT_DEBUG
-    if (!qEnvironmentVariable("XDG_SESSION_TYPE").contains("wayland")) {
+    if (!m_model->isUseWayland()) {
         setWindowFlags(Qt::WindowStaysOnTopHint | Qt::X11BypassWindowManagerHint);
     } else {
         setWindowFlags(windowFlags() | Qt::WindowStaysOnTopHint | Qt::FramelessWindowHint | Qt::Window);
@@ -72,7 +74,7 @@ FullscreenBackground::FullscreenBackground(SessionBaseModel *model, QWidget *par
     }
 #endif
     frameList.append(this);
-    m_useSolidBackground = getDConfigValue(getDefaultConfigFileName(), "use-solid-background", false).toBool();
+    m_useSolidBackground = getDConfigValue(getDefaultConfigFileName(), "useSolidBackground", false).toBool();
     m_enableAnimation = DGuiApplicationHelper::isSpecialEffectsEnvironment();
     if (m_enableAnimation && !m_useSolidBackground) {
         m_fadeOutAni = new QVariantAnimation(this);
@@ -91,6 +93,16 @@ FullscreenBackground::FullscreenBackground(SessionBaseModel *model, QWidget *par
             }
         });
     }
+
+    connect(qApp, &QGuiApplication::primaryScreenChanged, this, [this](QScreen *screen) {
+        qDebug() << "QGuiApplication::primaryScreenChanged:" << m_screen << screen << m_content;
+        if (!m_screen.isNull() && m_screen == screen && m_content) {
+            m_primaryShowFinished = true;
+        }
+    });
+
+    m_blackWidget->setBlackMode(m_model->isBlackMode());
+    connect(m_model, &SessionBaseModel::blackModeChanged, m_blackWidget, &BlackWidget::setBlackMode);
 }
 
 FullscreenBackground::~FullscreenBackground()
@@ -105,7 +117,7 @@ void FullscreenBackground::updateBackground(const QString &path)
 
     if (isPicture(path)) {
         // 动画播放完毕不再需要清晰的背景图片
-        if (!m_fadeOutAniFinished) {
+        if (!m_fadeOutAniFinished && !(backgroundPath == path && contains(PIXMAP_TYPE_BACKGROUND))) {
             backgroundPath = path;
             addPixmap(pixmapHandle(QPixmap(path)), PIXMAP_TYPE_BACKGROUND);
         }
@@ -118,27 +130,32 @@ void FullscreenBackground::updateBackground(const QString &path)
 
 void FullscreenBackground::updateBlurBackground(const QString &path)
 {
-    QDBusPendingCall call = m_imageEffectInter->Get("", path);
-    QDBusPendingCallWatcher *watcher = new QDBusPendingCallWatcher(call, this);
-    connect(watcher, &QDBusPendingCallWatcher::finished, [=] {
-        if (!call.isError()) {
-            QDBusReply<QString> reply = call.reply();
-            QString path = reply.value();
-            if (!isPicture(path)) {
-                path = "/usr/share/backgrounds/default_background.jpg";
+    QDBusPendingCall async = m_imageEffectInter->Get("", path);
+    QDBusPendingCallWatcher *watcher = new QDBusPendingCallWatcher(async, this);
+    connect(watcher, &QDBusPendingCallWatcher::finished, this, [this] (QDBusPendingCallWatcher *call) {
+        const QDBusPendingReply<QString> reply = *call;
+        if (!reply.isError()) {
+            QString blurPath = reply.value();
+
+            if (!isPicture(blurPath)) {
+                blurPath = "/usr/share/backgrounds/default_background.jpg";
             }
-            blurBackgroundPath = path;
-            addPixmap(pixmapHandle(QPixmap(path)), PIXMAP_TYPE_BLUR_BACKGROUND);
+
+            if (blurBackgroundPath != blurPath || !contains(PIXMAP_TYPE_BLUR_BACKGROUND)) {
+                blurBackgroundPath = blurPath;
+                addPixmap(pixmapHandle(QPixmap(blurPath)), PIXMAP_TYPE_BLUR_BACKGROUND);
+            }
+
             // 只播放一次动画，后续背景图片变更直接更新模糊壁纸即可
             if (m_fadeOutAni && !m_fadeOutAniFinished)
                 m_fadeOutAni->start();
             else
                 update();
         } else {
-            qWarning() << "get blur background image error: " << call.error().message();
+            qWarning() << "get blur background image error: " << reply.error().message();
         }
-        watcher->deleteLater();
-    });
+        call->deleteLater();
+    }, Qt::QueuedConnection);
 }
 
 bool FullscreenBackground::contentVisible() const
@@ -151,10 +168,15 @@ void FullscreenBackground::setEnterEnable(bool enable)
     m_enableEnterEvent = enable;
 }
 
-void FullscreenBackground::setScreen(QScreen *screen, bool isVisible)
+void FullscreenBackground::setScreen(QPointer<QScreen> screen, bool isVisible)
 {
+    if (screen.isNull())
+        return;
+
+    qInfo() << Q_FUNC_INFO << ", init screen:" << screen << " screen geometry:"
+            << screen->geometry() << " lockframe:" << this;
     QScreen *primary_screen = QGuiApplication::primaryScreen();
-    if (primary_screen == screen && !m_isBlackMode && isVisible) {
+    if (primary_screen == screen && isVisible) {
         m_content->show();
         m_primaryShowFinished = true;
         emit contentVisibleChanged(true);
@@ -179,38 +201,21 @@ void FullscreenBackground::setContentVisible(bool visible)
     if (!isVisible() && !visible)
         return;
 
-    m_content->setVisible(visible && !m_isBlackMode);
+    m_content->setVisible(visible);
 
-    emit contentVisibleChanged(visible && !m_isBlackMode);
+    emit contentVisibleChanged(visible);
 }
 
 void FullscreenBackground::setContent(QWidget *const w)
 {
     m_content = w;
     m_content->setParent(this);
-    m_content->raise();
     m_content->move(0, 0);
     m_content->setFocus();
     setFocusProxy(m_content);
-}
-
-void FullscreenBackground::setIsBlackMode(bool isBlack)
-{
-    if (m_isBlackMode == isBlack)
-        return;
-
-    //黑屏的同时隐藏鼠标,唤醒后显示鼠标
-    setCursor(isBlack ? Qt::BlankCursor : m_originalCursor);
-
-    //黑屏鼠标在多屏间移动时不显示界面
-    m_enableEnterEvent = !isBlack;
-    m_isBlackMode = isBlack;
-
-    m_content->setVisible(!m_isBlackMode);
-    emit contentVisibleChanged(!m_isBlackMode);
-
-    update();
-    raise();
+    // 如果是黑屏状态则不置顶
+    if (!m_blackWidget->isVisible())
+        m_content->raise();
 }
 
 void FullscreenBackground::setIsHibernateMode()
@@ -242,14 +247,12 @@ void FullscreenBackground::paintEvent(QPaintEvent *e)
     const QPixmap &blurBackground = getPixmap(PIXMAP_TYPE_BLUR_BACKGROUND);
 
     const QRect trueRect(QPoint(0, 0), QSize(size() * devicePixelRatioF()));
-    if (m_isBlackMode) {
-        painter.fillRect(trueRect, Qt::black);
-    } else if (m_useSolidBackground) {
+    if (m_useSolidBackground) {
         painter.fillRect(trueRect, QColor(DDESESSIONCC::SOLID_BACKGROUND_COLOR));
     } else {
         if (m_fadeOutAni) {
             const double currentAniValue = m_fadeOutAni->currentValue().toDouble();
-            if (!background.isNull() && currentAniValue != 1) {
+            if (!background.isNull() && currentAniValue != 1.0) {
                 painter.setOpacity(1);
                 painter.drawPixmap(trueRect,
                                 background,
@@ -275,7 +278,7 @@ void FullscreenBackground::paintEvent(QPaintEvent *e)
 
 void FullscreenBackground::tryActiveWindow(int count/* = 9*/)
 {
-    if (count < 0 || qgetenv("XDG_SESSION_TYPE").contains("wayland"))
+    if (count < 0 || m_model->isUseWayland())
         return;
 
     qCDebug(DDE_SS) << "try active window..." << count;
@@ -314,6 +317,7 @@ void FullscreenBackground::leaveEvent(QEvent *event)
 
 void FullscreenBackground::resizeEvent(QResizeEvent *event)
 {
+    m_blackWidget->resize(size());
     m_content->resize(size());
     if (isPicture(backgroundPath) && !contains(PIXMAP_TYPE_BACKGROUND))
         addPixmap(pixmapHandle(QPixmap(backgroundPath)), PIXMAP_TYPE_BACKGROUND);
@@ -331,12 +335,12 @@ void FullscreenBackground::resizeEvent(QResizeEvent *event)
  */
 void FullscreenBackground::mouseMoveEvent(QMouseEvent *event)
 {
-    if (!m_isBlackMode && m_model->visible()) {
+    if (m_model->visible() && m_enableEnterEvent) {
         m_content->show();
         emit contentVisibleChanged(true);
     }
 
-    return QWidget::mouseMoveEvent(event);
+    QWidget::mouseMoveEvent(event);
 }
 
 void FullscreenBackground::keyPressEvent(QKeyEvent *e)
@@ -356,27 +360,22 @@ void FullscreenBackground::keyPressEvent(QKeyEvent *e)
 
 void FullscreenBackground::showEvent(QShowEvent *event)
 {
-    bool isWayLand = qgetenv("XDG_SESSION_TYPE").contains("wayland");
-    if (QWindow *w = windowHandle()) {
-        if (m_screen) {
-            if (w->screen() != m_screen) {
-                w->setScreen(m_screen);
-            }
-
-            // 更新窗口位置和大小
-            updateGeometry();
-        } else {
-            updateScreen(w->screen());
-        }
-
-        if (!isWayLand) {
-            connect(w, &QWindow::screenChanged, this, &FullscreenBackground::updateScreen, Qt::DirectConnection);
-        }
+    if (m_model->isUseWayland()) {
+        Q_EMIT requestDisableGlobalShortcutsForWayland(true);
     }
 
+    updateGeometry();
     return QWidget::showEvent(event);
 }
 
+void FullscreenBackground::hideEvent(QHideEvent *event)
+{
+    if (m_model->isUseWayland()) {
+        Q_EMIT requestDisableGlobalShortcutsForWayland(false);
+    }
+    QWidget::hideEvent(event);
+}
+
 const QPixmap FullscreenBackground::pixmapHandle(const QPixmap &pixmap)
 {
     const QSize trueSize {size() * devicePixelRatioF()};
@@ -395,25 +394,35 @@ const QPixmap FullscreenBackground::pixmapHandle(const QPixmap &pixmap)
     return pix;
 }
 
-void FullscreenBackground::updateScreen(QScreen *screen)
+void FullscreenBackground::updateScreen(QPointer<QScreen> screen)
 {
     if (screen == m_screen)
         return;
 
-    if (m_screen)
+    if (!m_screen.isNull())
         disconnect(m_screen, &QScreen::geometryChanged, this, &FullscreenBackground::updateGeometry);
 
-    if (screen)
+    if (!screen.isNull()) {
+        connect(screen, &QScreen::geometryChanged, [=](){
+            qInfo() << "screen geometry changed:" << screen << " lockframe:" << this;
+        });
         connect(screen, &QScreen::geometryChanged, this, &FullscreenBackground::updateGeometry);
+    }
 
     m_screen = screen;
-    if (m_screen)
-        updateGeometry();
+
+    updateGeometry();
 }
 
 void FullscreenBackground::updateGeometry()
 {
-    setGeometry(m_screen->geometry());
+    qInfo() << "set background screen:" << m_screen;
+
+    if (!m_screen.isNull()) {
+        setGeometry(m_screen->geometry());
+        qInfo() << "set background geometry:" << m_screen << m_screen->geometry() << "lockFrame:"
+                << this  << " lockframe geometry:" << this->geometry();
+    }
 }
 
 /********************************************************
@@ -438,13 +447,10 @@ const QPixmap& FullscreenBackground::getPixmap(int type)
     static QPixmap pixmap;
 
     const QSize &size = trueSize();
-    auto findPixmap = [ this, size ] (QList<QPair<QSize, QPixmap>> &list) -> const QPixmap & {
-        for (const auto &pair : list) {
-            if (pair.first == size)
-                return pair.second;
-        }
-
-        return pixmap;
+    auto findPixmap = [size](QList<QPair<QSize, QPixmap>> &list) -> const QPixmap & {
+        auto it = std::find_if(list.begin(), list.end(),
+                               [size](QPair<QSize, QPixmap> pair) { return pair.first == size; });
+        return it != list.end() ? it.i->t().second : pixmap;
     };
 
     if (PIXMAP_TYPE_BACKGROUND == type)
@@ -491,13 +497,11 @@ void FullscreenBackground::addPixmap(const QPixmap &pixmap, const int type)
  */
 void FullscreenBackground::updatePixmap()
 {
-    auto isNoUsefunc = [ ] (const QSize &size) -> bool {
-        for (FullscreenBackground * frame : frameList) {
-            if (frame->trueSize() == size) {
-                return false;
-            }
-        }
-        return true;
+    auto isNoUsefunc = [](const QSize &size) -> bool {
+        bool b = std::any_of(frameList.begin(), frameList.end(), [size](FullscreenBackground *frame) {
+            return frame->trueSize() == size;
+        });
+        return !b;
     };
 
     auto updateFunc = [ isNoUsefunc ] (QList<QPair<QSize, QPixmap>> &list) {
@@ -513,12 +517,11 @@ void FullscreenBackground::updatePixmap()
 
 bool FullscreenBackground::contains(int type)
 {
-    auto containsFunc = [ this ] (QList<QPair<QSize, QPixmap>> &list) -> bool {
-        for (const auto &pair : list) {
-            if (pair.first == trueSize())
-                return true;
-        }
-        return false;
+    auto containsFunc = [this](QList<QPair<QSize, QPixmap>> &list) -> bool {
+        bool b = std::any_of(list.begin(), list.end(), [this](QPair<QSize, QPixmap> &pair) {
+            return pair.first == trueSize();
+        });
+        return b;
     };
 
     if (PIXMAP_TYPE_BACKGROUND == type)
@@ -526,3 +529,9 @@ bool FullscreenBackground::contains(int type)
     else
         return containsFunc(blurBackgroundCacheList);
 }
+
+void FullscreenBackground::moveEvent(QMoveEvent *event)
+{
+    qInfo() << "FullscreenBackground::moveEvent: " << ", old pos: " << event->oldPos() << ", pos: " << event->pos();
+    QWidget::moveEvent(event);
+}
