@@ -35,6 +35,7 @@ Q_DECLARE_LOGGING_CATEGORY(DDE_SS)
 
 using ImageEffectInter = com::deepin::daemon::ImageEffect;
 
+class BlackWidget;
 class SessionBaseModel;
 class FullscreenBackground : public QWidget
 {
@@ -43,7 +44,7 @@ class FullscreenBackground : public QWidget
 
 public:
     explicit FullscreenBackground(SessionBaseModel *model, QWidget *parent = nullptr);
-    ~FullscreenBackground();
+    ~FullscreenBackground() override;
 
     bool contentVisible() const;
     void setEnterEnable(bool enable);
@@ -51,20 +52,22 @@ public:
 public slots:
     void updateBackground(const QString &path);
     void updateBlurBackground(const QString &path);
-    void setScreen(QScreen *screen, bool isVisible = true);
+    void setScreen(QPointer<QScreen> screen, bool isVisible = true);
     void setContentVisible(bool visible);
-    void setIsBlackMode(bool isBlack);
     void setIsHibernateMode();
 
 signals:
     void contentVisibleChanged(bool contentVisible);
+    void requestDisableGlobalShortcutsForWayland(bool enable);
 
 protected:
     void setContent(QWidget *const w);
     void keyPressEvent(QKeyEvent *e) Q_DECL_OVERRIDE;
     void showEvent(QShowEvent *event) override;
+    void hideEvent(QHideEvent *event) override;
     bool event(QEvent *e) override;
     void resizeEvent(QResizeEvent *event) Q_DECL_OVERRIDE;
+    void moveEvent(QMoveEvent *event) Q_DECL_OVERRIDE;
 
 private:
     void paintEvent(QPaintEvent *e) Q_DECL_OVERRIDE;
@@ -72,7 +75,7 @@ private:
     void leaveEvent(QEvent *event) Q_DECL_OVERRIDE;
     void mouseMoveEvent(QMouseEvent *event) Q_DECL_OVERRIDE;
     const QPixmap pixmapHandle(const QPixmap &pixmap);
-    void updateScreen(QScreen *screen);
+    void updateScreen(QPointer<QScreen> screen);
     void updateGeometry();
     bool isPicture(const QString &file);
     QString getLocalFile(const QString &file);
@@ -95,15 +98,15 @@ private:
     ImageEffectInter *m_imageEffectInter; // 获取模糊背景服务
 
     QPointer<QWidget> m_content;
-    QScreen *m_screen = nullptr;
+    QPointer<QScreen> m_screen;
     SessionBaseModel *m_model = nullptr;
     bool m_primaryShowFinished = false;
-    bool m_isBlackMode = false;
     bool m_enableEnterEvent = true;
-    QCursor m_originalCursor;
     bool m_useSolidBackground;
     bool m_fadeOutAniFinished;
     bool m_enableAnimation;
+
+    BlackWidget *m_blackWidget;
 };
 
 #endif // FULLSCREENBACKGROUND_H
