@@ -26,6 +26,9 @@
 #include "shutdownwidget.h"
 #include "multiuserswarningview.h"
 #include "../global_util/gsettingwatcher.h"
+#include "../global_util/public_func.h"
+
+#include <DConfig>
 
 #if 0 // storage i10n
 QT_TRANSLATE_NOOP("ShutdownWidget", "Shut down"),
@@ -34,12 +37,15 @@ QT_TRANSLATE_NOOP("ShutdownWidget", "Suspend"),
 QT_TRANSLATE_NOOP("ShutdownWidget", "Hibernate")
 #endif
 
+DCORE_USE_NAMESPACE
+
 ShutdownWidget::ShutdownWidget(QWidget *parent)
     : QFrame(parent)
     , m_index(-1)
     , m_model(nullptr)
     , m_systemMonitor(nullptr)
     , m_switchosInterface(new HuaWeiSwitchOSInterface("com.huawei", "/com/huawei/switchos", QDBusConnection::sessionBus(), this))
+    , m_dconfig(DConfig::create(getDefaultConfigFileName(), getDefaultConfigFileName(), QString(), this))
 {
     m_frameDataBind = FrameDataBind::Instance();
 
@@ -54,7 +60,7 @@ ShutdownWidget::ShutdownWidget(QWidget *parent)
     std::function<void (QVariant)> function = std::bind(&ShutdownWidget::onOtherPageChanged, this, std::placeholders::_1);
     int index = m_frameDataBind->registerFunction("ShutdownWidget", function);
 
-    connect(this, &ShutdownWidget::destroyed, this, [ = ] {
+    connect(this, &ShutdownWidget::destroyed, this, [this, index] {
         m_frameDataBind->unRegisterFunction("ShutdownWidget", index);
     });
     installEventFilter(this);
@@ -109,6 +115,14 @@ void ShutdownWidget::initConnect()
     if (m_systemMonitor) {
         connect(m_systemMonitor, &SystemMonitor::requestShowSystemMonitor, this, &ShutdownWidget::runSystemMonitor);
     }
+
+    connect(m_dconfig, &DConfig::valueChanged, this, [this] (const QString &key) {
+        if (key == "hideLogoutButton") {
+            if (m_requireLogoutButton && m_model->currentModeState() == SessionBaseModel::ModeStatus::ShutDownMode) {
+                m_requireLogoutButton->setVisible(!m_dconfig->value("hideLogoutButton", false).toBool());
+            }
+        }
+    });
 }
 
 void ShutdownWidget::updateTr(RoundItemButton *widget, const QString &tr)
@@ -151,16 +165,6 @@ void ShutdownWidget::onOtherPageChanged(const QVariant &value)
     m_currentSelectedBtn->updateState(RoundItemButton::Checked);
 }
 
-void ShutdownWidget::hideToplevelWindow()
-{
-    QWidgetList widgets = qApp->topLevelWidgets();
-    for (QWidget *widget : widgets) {
-        if (widget->isVisible()) {
-            widget->hide();
-        }
-    }
-}
-
 void ShutdownWidget::enterKeyPushed()
 {
     if (m_systemMonitor && m_systemMonitor->state() == SystemMonitor::Enter) {
@@ -246,6 +250,7 @@ void ShutdownWidget::initUI()
     m_requireLogoutButton->setAccessibleName("RequireLogoutButton");
     m_requireLogoutButton->setObjectName("RequireLogoutButton");
     m_requireLogoutButton->setAutoExclusive(true);
+    m_requireLogoutButton->setVisible(!m_dconfig->value("hideLogoutButton", false).toBool());
     updateTr(m_requireLogoutButton, "Log out");
 
     m_requireSwitchUserBtn = new RoundItemButton(tr("Switch user"));
@@ -404,7 +409,7 @@ void ShutdownWidget::onStatusChanged(SessionBaseModel::ModeStatus status)
         if (m_requireSwitchSystemBtn) {
             m_requireSwitchSystemBtn->setVisible(true);
         }
-        m_requireLogoutButton->setVisible(true);
+        m_requireLogoutButton->setVisible(!m_dconfig->value("hideLogoutButton", false).toBool());
         roundItemButton = m_requireLockButton;
     } else {
         m_requireLockButton->setVisible(false);
@@ -434,7 +439,7 @@ void ShutdownWidget::runSystemMonitor()
         m_systemMonitor->setState(SystemMonitor::Leave);
     }
 
-    hideToplevelWindow();
+    m_model->setVisible(false);
 }
 
 void ShutdownWidget::recoveryLayout()
@@ -561,6 +566,7 @@ void ShutdownWidget::showEvent(QShowEvent *event)
 
 void ShutdownWidget::updateLocale(std::shared_ptr<User> user)
 {
+    Q_UNUSED(user)
     //只有登陆界面才需要根据系统切换语言
     if(qApp->applicationName() == "dde-lock") return;
 
