@@ -42,7 +42,7 @@ class WarningContent : public SessionBaseWindow
 
 public:
     explicit WarningContent(SessionBaseModel *const model, const SessionBaseModel::PowerAction action, QWidget *parent = nullptr);
-    ~WarningContent();
+    ~WarningContent() override;
     void beforeInvokeAction(bool needConfirm);
     void setPowerAction(const SessionBaseModel::PowerAction action);
 
